@@ -34,9 +34,7 @@
  * when serialized using XDR.
  */
 
-#include <sys/cdefs.h>
 
-#include "namespace.h"
 #include <rpc/types.h>
 #include <rpc/xdr.h>
 #include <sys/types.h>
