@@ -97,18 +97,6 @@ struct des_clnt_data32 {
 };
 #endif /* _SYSCALL32_IMPL */
 
-#ifdef KERBEROS
-/*
- * flavor specific data to hold the data for AUTH_DES/AUTH_KERB(v4)
- * in sec_data->data opaque field.
- */
-typedef struct krb4_svc_data {
-	int		window;		/* window option value */
-} krb4_svcdata_t;
- 
-typedef struct krb4_svc_data	des_svcdata_t;
-#endif /* KERBEROS */
-
 /*
  * authentication/security specific flags
  */
@@ -134,7 +122,6 @@ enum auth_stat {
 	*/
 	AUTH_INVALIDRESP=6,		/* bogus response verifier */
 	AUTH_FAILED=7,			/* some unknown reason */
-#ifdef KERBEROS
 	/*
 	 * kerberos errors
 	 */
@@ -143,8 +130,6 @@ enum auth_stat {
 	AUTH_TKT_FILE = 10,		/* something wrong with ticket file */
 	AUTH_DECODE = 11,		/* can't decode authenticator */
 	AUTH_NET_ADDR = 12,		/* wrong net address in ticket */
-#endif /* KERBEROS */
-
 	/*
 	 * RPCSEC_GSS errors
 	 */
@@ -163,8 +148,6 @@ union des_block {
 	char c[8];
 };
 typedef union des_block des_block;
-
-#ifdef HAVE_AUTHDES
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -172,7 +155,6 @@ extern bool_t xdr_des_block(XDR *, des_block *);
 #ifdef __cplusplus
 }
 #endif
-#endif /* HAVE_AUTHDES */
 
 /*
  * Authentication info.  Opaque to client.
@@ -319,8 +301,6 @@ extern AUTH *authnone_create(void);		/* takes no parameters */
 #ifdef __cplusplus
 }
 #endif
-
-#ifdef HAVE_AUTHDES
 /*
  * DES style authentication
  * AUTH *authsecdes_create(servername, window, timehost, ckey)
@@ -338,7 +318,6 @@ extern AUTH *authdes_seccreate (const char *, const u_int, const  char *,
 #ifdef __cplusplus
 }
 #endif
-#endif /* HAVE_AUTHDES */
 
 #ifdef __cplusplus
 extern "C" {
@@ -362,53 +341,40 @@ extern int host2netname(char *, const char *, const char *);
 extern int user2netname(char *, const uid_t, const char *);
 extern int netname2user(char *, uid_t *, gid_t *, int *, gid_t *);
 extern int netname2host(char *, char *, const int);
-#ifdef HAVE_AUTHDES
 extern void passwd2des ( char *, char * );
-#endif /* HAVE_AUTHDES */
-#ifdef __cplusplus
-}
-#endif
-
-#ifdef KERBEROS
-/*
- * Kerberos style authentication
- * AUTH *authkerb_seccreate(service, srv_inst, realm, window, timehost, status)
- *	const char *service;			- service name
- *	const char *srv_inst;			- server instance
- *	const char *realm;			- server realm
- *	const u_int window;			- time to live
- *	const char *timehost;			- optional hostname to sync with
- *	int *status;				- kerberos status returned
- */
-#ifdef __cplusplus
-extern "C" {
-#endif
-extern AUTH	*authkerb_seccreate(const char *, const char *, const  char *,
-		    const u_int, const char *, int *);
 #ifdef __cplusplus
 }
 #endif
 
 /*
- * Map a kerberos credential into a unix cred.
  *
- *	authkerb_getucred(rqst, uid, gid, grouplen, groups)
- *	const struct svc_req *rqst;		- request pointer
- *	uid_t *uid;
- *	gid_t *gid;
- *	short *grouplen;
- *	int *groups;
+ * These routines interface to the keyserv daemon
  *
  */
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern int	authkerb_getucred(/* struct svc_req *, uid_t *, gid_t *,
-		    short *, int * */);
+extern int key_decryptsession(const char *, des_block *);
+extern int key_encryptsession(const char *, des_block *);
+extern int key_gendes(des_block *);
+extern int key_setsecret(const char *);
+extern int key_secretkey_is_set(void);
+#ifdef __cplusplus
+}
+#endif
+
+/*
+ * Publickey routines.
+ */
+#ifdef __cplusplus
+extern "C" {
+#endif
+extern int getpublickey (const char *, char *);
+extern int getpublicandprivatekey (char *, char *);
+extern int getsecretkey (char *, char *, char *);
 #ifdef __cplusplus
 }
 #endif
-#endif /* KERBEROS */
 
 #ifdef __cplusplus
 extern "C" {
